/*------------------------------------------------------------------------
   (C) Copyright Marxmeier Software AG, 2021

   eqdbobj.h - Eloquence database binary object utility functions
   $Id: eqdbobj.h,v 29.2 2023/11/13 15:07:36 rhg Exp $

   Edit History:
   15.06.2021, initial release

------------------------------------------------------------------------*/

#if !defined(DBOBJ_INCLUDED)
#define DBOBJ_INCLUDED

#define DBOBJ_VER 0x8400

#if defined(__cplusplus)
extern "C" {
#endif

int idb_obj_ctrl(int mode, int nval, int *oval);

int idb_obj_putdata(int mode, const void *data, size_t data_sz);
int idb_obj_getdata(int mode, void *buf, size_t buf_sz, size_t *len);

int idb_obj_fetch(
   int dbid, const void *set, unsigned int id, size_t *len_p);

int idb_obj_delete(
   int dbid, const void *set, unsigned int id);

int idb_obj_store(
   int dbid, const void *set, int mode, unsigned int id);

const char *idb_obj_msg(int stat);

enum DBOBJ_STATUS {
   DBOBJ_OK = 0,
   DBOBJ_ERR_DB = -1,          /* unexpected db status */
   DBOBJ_ERR_SET = -2,         /* invalid or improper data set */
   DBOBJ_NOTFOUND = 3,         /* object not found */
   DBOBJ_EXISTS = 4,           /* object already exists */
   DBOBJ_ERR_LOCK = -5,        /* database locking failed */
   DBOBJ_ERR_MEMALLOC = -6,    /* memory allocation failed */
   DBOBJ_ERR_CORRUPT = -7,     /* object data inconsistent */
   DBOBJ_ERR_ZLIB = -8,        /* zlib call failed */
   DBOBJ_ERR_BADMODE = -9,     /* bad mode value */
   DBOBJ_ERR_BADARG  = -10,    /* bad argument value */
   DBOBJ_ERR_NODATA = 11,      /* no data passed (sequence error) */
   DBOBJ_ERR_LIMIT = 12        /* data size exceeds limit */
};

void dbobjctrl(
  const void *mode, void *status, const void *nval, void *oval);

void dbobjputdata(
  const void *mode, void *status, const void *data, const void *len);
void dbobjgetdata(
  const void *mode, void *status, void *buf, const void *buf_sz, 
  void *len);

void dbobjfetch(
   const void *base, const void *dset, void *status, 
   const void *id, void *len);

void dbobjdelete(
   const void *base, const void *dset, void *status,
   const void *id);

void dbobjstore(
   const void *base, const void *dset, const void *mode,
   void *status, const void *id);

extern const char dbobj__version_tag[];
extern const char dbobj__copyright[];
extern const char dbobj__patchlevel[];

#if defined(__cplusplus)
}
#endif

#endif /* DBOBJ_INCLUDED */
